@@ -14,7 +14,7 @@ sed \
   -e 's/^\t<\/ul>/\t<\/ul><\/li>/' \
   -e 's/^<p>&#10;/<p>/' \
   -e 's/^&#10;/<br \/>/g' \
-  -e 's/mailto:root@localhost/mailto:mikio@users.sourceforge.net/' \
+  -e 's/mailto:root@localhost/mailto:info@fallabs.com/' \
   -e 's/ *style="[^"]*"//' \
   -e '/<\/head>/ i<meta http-equiv="content-style-type" content="text/css" />' \
   -e '/<\/head>/ i<style type="text/css">body {\
